Credits
=======

* `Diederik Veeze <https://github.com/didrix>`_ (Zest Software) is the
  creator of collective.ogtags.

* `Maurits van Rees <https://github.com/mauritsvanrees>`_ (Zest Software) is the
  maintainer of collective.ogtags.
  
* `Jean-Paul Ladage <https://github.com/jladage>`_ (Zest Software) is another
  maintainer of collective.ogtags.

* `Fred van Dijk <https://github.com/fredvd>`_ (Zest Software) is another
  maintainer of collective.ogtags.

* `Matteo Parrucci <https://github.com/parruc>`_ (Bologna university) is a
  simple contributor of collective.ogtags.
